@@ -2,8 +2,7 @@ import sys
 import convertible
 import inspect
 import traceback
-import logging
-import httplib
+
 
 def call(func, kwargs):
     argspec = inspect.getargspec(func)
@@ -23,9 +22,6 @@ def respond(result, message=None, success=True):
 
 
 def run(runner, debug=False):
-    if debug:
-        logging.basicConfig(level=logging.DEBUG)
-        httplib.HTTPConnection.debuglevel = 1
     try:
         data = runner()
         respond(data)
@@ -38,6 +34,7 @@ def run(runner, debug=False):
         respond(e, str(e), success=False)
         exit(1)
 
+
 def execute(obj, args):
     method = getattr(obj, args.action)
     run(lambda: call(method, vars(args)), args.debug)
